/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.util.swing;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.Serializable;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.openide.util.Exceptions;

/**
 *
 * @author Timon Veenstra
 */
public class BoundInlineEditLabel extends InlineEditLabel  implements Serializable{

    private static final String METHOD_ADD_PCL = "addPropertyChangeListener";
    private static final String METHOD_REMOVE_PCL = "removePropertyChangeListener";
    private Object bean;
    private String property;
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.util.swing");

    public void setBoundProperty(final Object bean, final String property) {
        this.bean = bean;
        this.property = property;
        initialize();
    }

    private void initialize() {

        setValue(getBoundValue());

        try {
            Method addPCLMethod = bean.getClass().getDeclaredMethod(METHOD_ADD_PCL, PropertyChangeListener.class);
            addPCLMethod.invoke(bean, new PropertyChangeListener() {

                @Override
                public void propertyChange(PropertyChangeEvent evt) {
                    if (property.equals(evt.getPropertyName())) {
                        setValue(getValue());
                    }
                }
            });
        } catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException | NoSuchMethodException | SecurityException ex) {
            LOGGER.log(Level.WARNING, "Failure in adding listener to bound value on bean, {0}", ex.getMessage());
        }
    }

    public void setBoundValue(String newValue) {
        try {
            StringBuilder sb = new StringBuilder("set");
            sb.append(property.substring(0, 1).toUpperCase());
            sb.append(property.substring(1, property.length()));
            Method setMethod = bean.getClass().getDeclaredMethod(sb.toString(), String.class);
            setMethod.invoke(bean, newValue);
        } catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException | NoSuchMethodException | SecurityException ex) {
            LOGGER.log(Level.WARNING, "Failure in changing value of bound property on bean, {0}", ex.getMessage());
        }
    }

    public String getBoundValue() {
        try {
            StringBuilder sb = new StringBuilder("get");
            sb.append(property.substring(0, 1).toUpperCase());
            sb.append(property.substring(1, property.length()));
            Method getMethod = bean.getClass().getDeclaredMethod(sb.toString());
            Object value = getMethod.invoke(bean);
            return (value != null) ? value.toString() : null;
        } catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException | NoSuchMethodException | SecurityException ex) {
            LOGGER.log(Level.WARNING, "Failure in retrieving bound value from bean, {0}", ex.getMessage());
        }
        return null;
    }

    public Object getBean() {
        return bean;
    }

    public void setBean(Object bean) {
        this.bean = bean;
        if (this.property != null){
            initialize();
        }
    }

    public String getProperty() {
        return property;
    }

    public void setProperty(String property) {
        this.property = property;
        if (this.bean != null){
            initialize();
        }        
    }
}
