/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.util.swing.icon;

import java.awt.Component;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Point;
import java.util.EnumMap;
import java.util.Map;
import javax.swing.Icon;

/**
 * Icon, that allows you to set badge icon.
 * 
 * @author Frantisek Post
 */
public class BadgeIcon implements Icon {

    private Icon baseIcon;
    private Map<BadgePosition, Icon> badgeMap;

    public BadgeIcon(Icon baseIcon) {
        this();
        setBaseIcon(baseIcon);
    }
    
    public BadgeIcon() {
        badgeMap = new EnumMap<>(BadgePosition.class);
    }

    @Override
    public void paintIcon(Component c, Graphics g, int x, int y) {

        baseIcon.paintIcon(c, g, x, y);
        Dimension baseDimension = new Dimension(baseIcon.getIconWidth(), baseIcon.getIconHeight());

        for (Map.Entry<BadgePosition, Icon> entry : badgeMap.entrySet()) {
            Icon icon = entry.getValue();
            Point p = entry.getKey().getBadgePosition(baseDimension, new Dimension(icon.getIconWidth(), icon.getIconHeight()));
            icon.paintIcon(c, g, x + p.x, y + p.y);
        }
    }

    @Override
    public int getIconWidth() {
        return baseIcon.getIconWidth();
    }

    @Override
    public int getIconHeight() {
        return baseIcon.getIconHeight();
    }

    // API
    public void setBaseIcon(Icon baseIcon) {
        assert baseIcon != null;
        this.baseIcon = baseIcon;
    }

    public Icon getBaseIcon() {
        return baseIcon;
    }

    public void setBadge(Icon icon, BadgePosition badgePosition) {
        assert icon != null;
        assert badgePosition != null;
        badgeMap.put(badgePosition, icon);
    }

    public Icon getBadge(BadgePosition badgePosition) {
        return badgeMap.get(badgePosition);
    }
}
